#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: api.py 11616 2019-06-07 02:15:46Z Andy $
#
# Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Andy $
# $Date: 2019-06-07 11:15:46 +0900 (週五, 07 六月 2019) $
# $Revision: 11616 $

from django.conf.urls import url

from Theophrastus.integration import views

urlpatterns = [
#    url(r'^user/exist/$', views.checkUserExist,
#        name='Theophrastus.api.userExist'),

    url(r'^app/login/$', views.login, name='Theophrastus.api.login'),
    url(r'^app/mail/$', views.mail, name='Theophrastus.api.mail'),
]

